@@ -1,14 +1,15 @@
 #!/bin/sh
 echo 'name: hslogger
-version: 1.1.0
-id: hslogger-1.1.0-48a3b1fc56e6e7d3c3f60d3e5a41095d
+version: 1.1.5
+id: hslogger-1.1.5-13adda0b39a0331b6f8f7322430839f1
 
-license: LGPL
-copyright: Copyright (c) 2004-2010 John Goerzen
+license: BSD3
+copyright: Copyright (c) 2004-2011 John Goerzen
 maintainer: John Goerzen <jgoerzen@complete.org>
 stability: Stable
 homepage: http://software.complete.org/hslogger
 package-url:
+synopsis: Versatile logging framework
 description: hslogger is a logging framework for Haskell, roughly similar to
              Python'\''s logging module.
              .
@@ -25,27 +26,28 @@ exposed-modules: System.Log System.Log.Handler System.Log.Formatter
                  System.Log.Handler.Growl System.Log.Handler.Log4jXML
                  System.Log.Logger
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/hslogger-1.1.0
-library-dirs: /usr/local/lib/ghc/hslogger-1.1.0
-hs-libraries: HShslogger-1.1.0
+trusted: False
+import-dirs: /usr/local/lib/ghc/hslogger-1.1.5
+library-dirs: /usr/local/lib/ghc/hslogger-1.1.5
+hs-libraries: HShslogger-1.1.5
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-912d55d387093f740e3bcd2ffbf1dd83
-         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
-         directory-1.1.0.0-9b4fc50fd8f1413dca2a5e01dd665f6d
-         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
-         network-2.3.0.2-51cd64b57afa0471aa34f65914adc9bc
-         old-locale-1.0.0.2-6e2a3c0744e8cf4e0ac2d4e58659f7b5
-         process-1.0.1.5-4cab1bf0666275ac101dd48c7565b64c
-         time-1.2.0.3-57ebba2cc05370f666b7eceba5e468a9
-         unix-2.4.2.0-d862aa68d5295ed626dcf07180c3eda2
+depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
+         directory-1.1.0.2-4b2070a8941d5c76e41241a2ac457927
+         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
+         network-2.3.1.0-e56ec3d5abd17b7b386690bf49d424ab
+         old-locale-1.0.0.4-b1d945ebea59a524cba400a524cb40aa
+         process-1.1.0.1-c55e7a2b0eb5149f070b14e14bea1c83
+         time-1.4-b8e1c3d423daa1e2c5470a82caf23b52
+         unix-2.5.1.1-c23dadb7ccff9eeb5d1df0bd91909ca9
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-hslogger-1.1.0/html/hslogger.haddock
-haddock-html: /usr/local/share/doc/hs-hslogger-1.1.0/html
+haddock-interfaces: /usr/local/share/doc/hs-hslogger-1.1.5/html/hslogger.haddock
+haddock-html: /usr/local/share/doc/hs-hslogger-1.1.5/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
